@@ -21,6 +21,7 @@ IMPORTANT_POS = [
     "VBP",
     "VBZ",
 ]
+IGNORE_SUFFIXES = ["", "s"]
 INFINITY = 10000
 
 # ---
@@ -90,6 +91,10 @@ def normaliseNotion(notion):
         if len(sp) <= 1:
             break
         notion_norm = sp[0] + sp[2]
+    while "\\-" in notion_norm:
+        # If the notion contains hyphenations, remove them.
+        sp = notion_norm.split("\\-", 1)
+        notion_norm = sp[0] + sp[1]
     while "\\" in notion_norm:
         # If the notion contains a backslash, remove every letter following the backslash
         # see https://tex.stackexchange.com/a/34381/206008 for naming conventions of TeX commands
@@ -135,8 +140,14 @@ def similarWords(w1, w2, list_prefixes, stemmer):
         s1 = stemmer.stem(w1)
         s2 = stemmer.stem(w2)
         for p in list_prefixes:
-            if p + s1 == s2 or p + s2 == s1:
-                return True
+            for s in IGNORE_SUFFIXES:
+                if (
+                    p + s1 + s == s2
+                    or p + s1 == s2 + s
+                    or s1 + s == p + s2
+                    or s1 == p + s2 + s
+                ):
+                    return True
         return False
 
 
